<h1>Hello, Welcome to ZinckLib</h1>

The main focus of this library is around the manipulation of strings between various forms like strings to numbers or 
converting a number to its written form. There are also some other tools like creating a list of prime numbers less than
a given value or determining if a string is in alphabetical order.

Documentation can be found at: https://zincklib.readthedocs.io

The repository can be found at: https://github.com/Zinckle/ZinckLib

The library is hosted here: https://pypi.org/project/ZinckLib/

You can check out my portfolio here: https://zinck.xyz

[![Downloads](https://static.pepy.tech/badge/zincklib)](https://pepy.tech/project/zincklib) [![Documentation Status](https://readthedocs.org/projects/zincklib/badge/?version=latest)](https://zincklib.readthedocs.io/en/latest/?badge=latest)

If there is anything you think I should add or anything you think I should change, feel free to reach out!
